@@ -495,7 +495,7 @@ class scapula():
 
         # 改变基座位置
         def change_jizuo(mesh_jizuo1):
-            a = - mesh_jizuo1.get_center() + [0, 0, 0]
+            a = - mesh_jizuo1.get_center() + [0, 0, 0] + [0, 0, 3]
             mesh_jizuo = copy.deepcopy(mesh_jizuo1).translate(tuple(a))
             mesh_jizuo.compute_vertex_normals()
             return mesh_jizuo
@@ -592,4 +592,4 @@ class scapula():
         self.jizuo = copy.deepcopy(mesh_jizuonew)
 
         #展示一下
-        # o3d.visualization.draw_geometries([mesh_cylindernew, mesh, mesh_sphere2, mesh_sphere, mesh_jizuonew])
\ No newline at end of file
+        # o3d.visualization.draw_geometries([mesh_cylindernew, mesh, mesh_sphere2, mesh_sphere, mesh_jizuonew])
